@@ -6,7 +6,7 @@ from django.db.models.constants import LOOKUP_SEP
 from django.db.models.fields.related import ForeignObjectRel
 from django.test import TestCase, override_settings
 from django.utils.functional import Promise
-from django.utils.timezone import get_default_timezone
+from django.utils.timezone import get_default_timezone, make_aware
 
 from django_filters import FilterSet
 from django_filters.exceptions import FieldLookupError
@@ -40,7 +40,7 @@ class MigrationNoticeTests(TestCase):
     def test_message(self):
         self.assertEqual(
             str(MigrationNotice('Message.')),
-            'Message. See: https://django-filter.readthedocs.io/en/master/guide/migration.html'
+            'Message. See: https://django-filter.readthedocs.io/en/main/guide/migration.html'
         )
 
 
@@ -222,6 +222,22 @@ class GetFieldPartsTests(TestCase):
         self.assertIsInstance(parts[1], models.ManyToManyField)
         self.assertIsInstance(parts[2], models.CharField)
 
+    def test_lazy_relationship_not_ready(self):
+        """
+        This simulates trying to create a FilterSet before the app registry has
+        been populated. Lazy relationships have not yet been resolved from their
+        strings into their remote model referencess.
+        """
+        class TestModel(models.Model):
+            fk = models.ForeignKey('remote.Model', on_delete=models.CASCADE)
+
+        msg = ("Unable to resolve relationship `fk__f` for `tests.TestModel`. "
+               "Django is most likely not initialized, and its apps registry "
+               "not populated. Ensure Django has finished setup before loading "
+               "`FilterSet`s.")
+        with self.assertRaisesMessage(RuntimeError, msg):
+            get_field_parts(TestModel, 'fk__f')
+
 
 class GetModelFieldTests(TestCase):
 
@@ -496,13 +512,19 @@ class HandleTimezone(TestCase):
     def test_handle_dst_ending(self):
         dst_ending_date = datetime.datetime(2017, 2, 18, 23, 59, 59, 999999)
         handled = handle_timezone(dst_ending_date, False)
-        self.assertEqual(handled, get_default_timezone().localize(dst_ending_date, False))
+        self.assertEqual(
+            handled,
+            make_aware(dst_ending_date, get_default_timezone(), False),
+        )
 
     @override_settings(TIME_ZONE='America/Sao_Paulo')
     def test_handle_dst_starting(self):
         dst_starting_date = datetime.datetime(2017, 10, 15, 0, 0, 0, 0)
         handled = handle_timezone(dst_starting_date, True)
-        self.assertEqual(handled, get_default_timezone().localize(dst_starting_date, True))
+        self.assertEqual(
+            handled,
+            make_aware(dst_starting_date, get_default_timezone(), True),
+        )
 
 
 class TranslateValidationDataTests(TestCase):
